#!/bin/bash

# 检查是否传入参数
if [ "$#" -ne 1 ]; then
    echo "Usage: $0 <DNS_ADDRESS>"
    exit 1
fi

# 获取参数
DNS_ADDRESS="$1"

# 检查 DNS 是否已配置
RESOLV_CONF="/etc/resolv.conf"
if grep -q "nameserver $DNS_ADDRESS" "$RESOLV_CONF"; then
    echo "The DNS address $DNS_ADDRESS is configured in $RESOLV_CONF."
else
    echo "The DNS address $DNS_ADDRESS is not configured in $RESOLV_CONF."
    exit 2
fi

# 检查 DNS 地址的有效性
echo "Checking DNS address $DNS_ADDRESS for reachability..."
current_hostname=$(hostname)
if nslookup $current_hostname $DNS_ADDRESS > /dev/null 2>&1; then
    echo "The DNS address $DNS_ADDRESS is valid and reachable."
else
    echo "The DNS address $DNS_ADDRESS is not valid or not reachable."
    exit 3
fi

exit 0