#!/bin/bash

# 检查是否提供域名参数
if [[ -z "$1" ]]; then
    echo "Usage: $0 <NTP server domain>"
    exit 1
fi

NTP_SERVER=$1
CONFIG_FILE="/etc/systemd/timesyncd.conf"

# 检查配置文件是否存在
if [[ ! -f "$CONFIG_FILE" ]]; then
    echo "Configuration file $CONFIG_FILE does not exist."
    exit 2
fi

# 检查配置文件中是否包含NTP域名
if grep -q "NTP=.*${NTP_SERVER}" "$CONFIG_FILE"; then
    echo "The NTP server $NTP_SERVER is configured in $CONFIG_FILE."
else
    echo "The NTP server $NTP_SERVER is NOT configured in $CONFIG_FILE."
    exit 3
fi

# 检查NTP服务是否正常
echo "Checking the NTP server status for $NTP_SERVER..."
ntp_status=$(ntpdate -q "$NTP_SERVER" 2>&1)

if echo "$ntp_status" | grep -q "no server suitable for synchronization found"; then
    echo "The NTP server $NTP_SERVER is not responding or not suitable for synchronization."
    exit 4
else
    echo "The NTP server $NTP_SERVER is responding and suitable for synchronization."
    echo "Details:"
    echo "$ntp_status"
fi

exit 0