#!/bin/bash

# 检查是否传入参数
if [ "$#" -ne 1 ]; then
    echo "Usage: $0 <IP_ADDRESS>"
    exit 1
fi

# 获取参数
IP_ADDRESS="$1"

# 文件路径
FILES=(
    "/etc/apt/sources.list.d/${IP_ADDRESS}.list"
    "/etc/apt/sources.list.d/nfsupdate.list"
)

# 检查文件是否存在及其内容的有效性
for FILE in "${FILES[@]}"; do
    if [ -f "$FILE" ]; then
        echo "File $FILE exists."

        # 解析文件中的地址
        while read -r LINE; do
            # 提取形如 "http://<IP>:<PORT>/" 的地址
            ADDRESS=$(echo "$LINE" | grep -oP "http://\K[0-9]+\.[0-9]+\.[0-9]+\.[0-9]+:[0-9]+")
            
            if [[ "$ADDRESS" == "$IP_ADDRESS"* ]]; then
                # 测试地址是否可达
                HOST=$(echo "$ADDRESS" | cut -d':' -f1)
                PORT=$(echo "$ADDRESS" | cut -d':' -f2)

                # 使用 nc 测试端口连通性
                if nc -z -w2 "$HOST" "$PORT"; then
                    echo "Address $ADDRESS in $FILE is reachable."
                else
                    echo "Address $ADDRESS in $FILE is unreachable."
                    exit 4
                fi
            fi
        done < "$FILE"
    else
        echo "File $FILE does not exist."
        exit 2
    fi
done

exit 0